[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

hyatt hyatt at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 07:28:22 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit 646d2dc79a9753e5f5f6591d6d0f013045dcd648
Author: hyatt <hyatt at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Sat Mar 8 02:16:10 2003 +0000

            better fix for text-decoration issue on time.com.
    
            Reviewed by mjs
    
            * khtml/css/cssstyleselector.cpp:
            * khtml/rendering/render_style.h:
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@3784 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog-2003-10-25 b/WebCore/ChangeLog-2003-10-25
index 049b796..e4c8334 100644
--- a/WebCore/ChangeLog-2003-10-25
+++ b/WebCore/ChangeLog-2003-10-25
@@ -1,5 +1,14 @@
 2003-03-07  David Hyatt  <hyatt at apple.com>
 
+        better fix for text-decoration issue on time.com.  
+	
+        Reviewed by mjs
+
+        * khtml/css/cssstyleselector.cpp:
+        * khtml/rendering/render_style.h:
+
+2003-03-07  David Hyatt  <hyatt at apple.com>
+
 	Fix for time.com regression.  Don't allow text-decoration to
 	apply to anchor elements with no href.
 	
diff --git a/WebCore/ChangeLog-2005-08-23 b/WebCore/ChangeLog-2005-08-23
index 049b796..e4c8334 100644
--- a/WebCore/ChangeLog-2005-08-23
+++ b/WebCore/ChangeLog-2005-08-23
@@ -1,5 +1,14 @@
 2003-03-07  David Hyatt  <hyatt at apple.com>
 
+        better fix for text-decoration issue on time.com.  
+	
+        Reviewed by mjs
+
+        * khtml/css/cssstyleselector.cpp:
+        * khtml/rendering/render_style.h:
+
+2003-03-07  David Hyatt  <hyatt at apple.com>
+
 	Fix for time.com regression.  Don't allow text-decoration to
 	apply to anchor elements with no href.
 	
diff --git a/WebCore/khtml/rendering/render_style.h b/WebCore/khtml/rendering/render_style.h
index ce7bc75..3977c05 100644
--- a/WebCore/khtml/rendering/render_style.h
+++ b/WebCore/khtml/rendering/render_style.h
@@ -831,6 +831,7 @@ public:
     void setTextAlign(ETextAlign v) { inherited_flags._text_align = v; }
     void setTextTransform(ETextTransform v) { inherited_flags._text_transform = v; }
     void addToTextDecorationsInEffect(int v) { inherited_flags._text_decorations |= v; }
+    void setTextDecorationsInEffect(int v) { inherited_flags._text_decorations = v; }
     void setTextDecoration(int v) { SET_VAR(visual, textDecoration, v); }
     void setDirection(EDirection v) { inherited_flags._direction = v; }
     void setLineHeight(Length v) { SET_VAR(inherited,line_height,v) }

diff --git a/WebCore/khtml/css/cssstyleselector.cpp b/WebCore/khtml/css/cssstyleselector.cpp
index 84e2c99..f4c5d7c 100644
--- a/WebCore/khtml/css/cssstyleselector.cpp
+++ b/WebCore/khtml/css/cssstyleselector.cpp
@@ -471,14 +471,23 @@ RenderStyle *CSSStyleSelector::styleForElement(ElementImpl *e)
         }
     }
 
     // Mutate the display to BLOCK for certain cases, e.g., if someone attempts to
     // position or float an inline, compact, or run-in.
-    if ((style->display() == INLINE || style->display() == COMPACT || style->display() == RUN_IN) &&
-        (style->position() == ABSOLUTE || style->position() == FIXED || style->floating() != FNONE))
-        style->setDisplay(BLOCK);
+    if (style->position() == ABSOLUTE || style->position() == FIXED || style->floating() != FNONE) {
+        if (style->display() == INLINE || style->display() == COMPACT ||
+            style->display() == RUN_IN) // || style->display() == INLINE_BLOCK) FIXME!!!
+            style->setDisplay(BLOCK);
+        else if (style->display() == INLINE_TABLE)
+            style->setDisplay(TABLE);
+    }
 
-    // Finally update our text decorations in effect.
-    style->addToTextDecorationsInEffect(style->textDecoration());
+    // Finally update our text decorations in effect, but don't allow text-decoration to percolate through
+    // tables, inline blocks, inline tables, or run-ins.
+    if (style->display() == TABLE || style->display() == INLINE_TABLE || style->display() == RUN_IN)
+        // || style->display() == INLINE_BLOCK) FIXME!
+        style->setTextDecorationsInEffect(style->textDecoration());
+    else
+        style->addToTextDecorationsInEffect(style->textDecoration());
 
     // Now return the style.
     return style;
@@ -2883,16 +2892,7 @@ void CSSStyleSelector::applyRule( int id, DOM::CSSValueImpl *value )
 		}
 	    }
         }
-
-        // In quirks mode, we simply ignore text-decoration declarations on links with no href.
-        // People write lousy stylesheets (e.g., the articles on time.com) where they say:
-        // a { text-decoration: underline; }
-        // instead of:
-        // :link { text-decoration: underline; }
-        // So <a name="foo"> that wraps a bunch of content ends up causing underlines to be drawn.
-        if (strictParsing || element->id() != ID_A || element->hasAnchor())
-            style->setTextDecoration(t);
-	break;
+        break;
     }
     case CSS_PROP__KONQ_FLOW_MODE:
         if(value->cssValueType() == CSSValue::CSS_INHERIT)
@@ -471,14 +471,23 @@ RenderStyle *CSSStyleSelector::styleForElement(ElementImpl *e)
     }
 
-    // Mutate the display to BLOCK for certain cases, e.g., if someone attempts to
+    // Mutate the display to BLOCK or TABLE for certain cases, e.g., if someone attempts to
     // position or float an inline, compact, or run-in.
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list